@@ -1,5 +1,5 @@
 
-from typing import Optional
+from typing import Optional, Tuple
 
 from paramak import ExtrudeMixedShape
 
@@ -19,6 +19,7 @@ class ExtrudeStraightShape(ExtrudeMixedShape):
         distance: float,
         stp_filename: Optional[str] = "ExtrudeStraightShape.stp",
         stl_filename: Optional[str] = "ExtrudeStraightShape.stl",
+        color: Optional[Tuple[float, float, float, Optional[float]]] = (1.0, 0.498, 0.0),
         **kwargs
     ):
 
@@ -27,5 +28,6 @@ class ExtrudeStraightShape(ExtrudeMixedShape):
             stp_filename=stp_filename,
             stl_filename=stl_filename,
             connection_type="straight",
+            color=color,
             **kwargs
         )
