@@ -1,5 +1,5 @@
 
-from typing import Optional
+from typing import Optional, Tuple
 
 from paramak import RotateMixedShape
 
@@ -20,6 +20,7 @@ class RotateStraightShape(RotateMixedShape):
         rotation_angle: Optional[float] = 360.0,
         stp_filename: Optional[str] = "RotateStraightShape.stp",
         stl_filename: Optional[str] = "RotateStraightShape.stl",
+        color: Optional[Tuple[float, float, float, Optional[float]]] = (0.89, 0.101, 0.109),
         **kwargs
     ):
 
@@ -27,6 +28,7 @@ class RotateStraightShape(RotateMixedShape):
             rotation_angle=rotation_angle,
             stp_filename=stp_filename,
             stl_filename=stl_filename,
+            color=color,
             connection_type="straight",
             **kwargs
         )
