@@ -50,7 +50,9 @@ class TestSubmersionTokamak(unittest.TestCase):
         number of components are created."""
 
         self.test_reactor.outboard_tf_coil_radial_thickness = 50
-        self.test_reactor.tf_coil_to_rear_blanket_radial_gap = 50
+        self.test_reactor.rear_blanket_to_tf_gap = 50
+        self.test_reactor.pf_coil_radial_position = [100]
+        self.test_reactor.pf_coil_vertical_position = [100]
         self.test_reactor.outboard_tf_coil_poloidal_thickness = 70
         self.test_reactor.number_of_tf_coils = 4
 
@@ -61,12 +63,13 @@ class TestSubmersionTokamak(unittest.TestCase):
         correct number of components are created."""
 
         self.test_reactor.outboard_tf_coil_radial_thickness = 50
-        self.test_reactor.tf_coil_to_rear_blanket_radial_gap = 50
         self.test_reactor.outboard_tf_coil_poloidal_thickness = 70
         self.test_reactor.pf_coil_vertical_thicknesses = [50, 50, 50, 50, 50]
         self.test_reactor.pf_coil_radial_thicknesses = [40, 40, 40, 40, 40]
-        self.test_reactor.pf_coil_to_tf_coil_radial_gap = 50
-        self.test_reactor.pf_coil_case_thickness = 10
+        self.test_reactor.pf_coil_radial_position = [100, 100, 200, 200, 100]
+        self.test_reactor.pf_coil_vertical_position = [100, -100, 200, -200, 0]
+        self.test_reactor.rear_blanket_to_tf_gap = 50
+        self.test_reactor.pf_coil_case_thicknesses = 10
         self.test_reactor.number_of_tf_coils = 4
 
         assert len(self.test_reactor.shapes_and_components) == 11
@@ -87,7 +90,7 @@ class TestSubmersionTokamak(unittest.TestCase):
             "minimal_SubmersionTokamak/supports.stp",
             "minimal_SubmersionTokamak/blanket.stp",
             "minimal_SubmersionTokamak/outboard_rear_blanket_wall.stp",
-            "minimal_SubmersionTokamak/Graveyard.stp",
+            "minimal_SubmersionTokamak/graveyard.stp",
         ]
 
         for output_filename in output_filenames:
@@ -101,9 +104,10 @@ class TestSubmersionTokamak(unittest.TestCase):
         os.system("rm -r pf_SubmersionTokamak")
 
         self.test_reactor.outboard_tf_coil_radial_thickness = 50
-        self.test_reactor.tf_coil_to_rear_blanket_radial_gap = 50
-        self.test_reactor.outboard_tf_coil_poloidal_thickness = 70
-        self.test_reactor.number_of_tf_coils = 4
+        self.test_reactor.pf_coil_vertical_thicknesses = [50, 50]
+        self.test_reactor.pf_coil_radial_thicknesses = [40, 40]
+        self.test_reactor.pf_coil_radial_position = [100, 100]
+        self.test_reactor.pf_coil_vertical_position = [100, -100]
 
         self.test_reactor.export_stp("pf_SubmersionTokamak")
 
@@ -116,7 +120,7 @@ class TestSubmersionTokamak(unittest.TestCase):
             "pf_SubmersionTokamak/supports.stp",
             "pf_SubmersionTokamak/blanket.stp",
             "pf_SubmersionTokamak/outboard_rear_blanket_wall.stp",
-            "pf_SubmersionTokamak/Graveyard.stp",
+            "pf_SubmersionTokamak/graveyard.stp",
         ]
 
         for output_filename in output_filenames:
@@ -130,12 +134,13 @@ class TestSubmersionTokamak(unittest.TestCase):
         os.system("rm -r tf_pf_SubmersionTokamak")
 
         self.test_reactor.outboard_tf_coil_radial_thickness = 50
-        self.test_reactor.tf_coil_to_rear_blanket_radial_gap = 50
         self.test_reactor.outboard_tf_coil_poloidal_thickness = 70
-        self.test_reactor.pf_coil_vertical_thicknesses = [50, 50, 50, 50, 50]
-        self.test_reactor.pf_coil_radial_thicknesses = [40, 40, 40, 40, 40]
-        self.test_reactor.pf_coil_to_tf_coil_radial_gap = 50
-        self.test_reactor.pf_coil_case_thickness = 10
+        self.test_reactor.pf_coil_vertical_thicknesses = [50, 50]
+        self.test_reactor.pf_coil_radial_thicknesses = [40, 40]
+        self.test_reactor.pf_coil_radial_position = [100, 100]
+        self.test_reactor.pf_coil_vertical_position = [100, -100]
+        self.test_reactor.rear_blanket_to_tf_gap = 50
+        self.test_reactor.pf_coil_case_thicknesses = 10
         self.test_reactor.number_of_tf_coils = 4
 
         self.test_reactor.export_stp("tf_pf_SubmersionTokamak")
@@ -149,7 +154,7 @@ class TestSubmersionTokamak(unittest.TestCase):
             "tf_pf_SubmersionTokamak/supports.stp",
             "tf_pf_SubmersionTokamak/blanket.stp",
             "tf_pf_SubmersionTokamak/outboard_rear_blanket_wall.stp",
-            "tf_pf_SubmersionTokamak/Graveyard.stp",
+            "tf_pf_SubmersionTokamak/graveyard.stp",
             "tf_pf_SubmersionTokamak/pf_coil_cases.stp"
         ]
 
@@ -183,11 +188,12 @@ class TestSubmersionTokamak(unittest.TestCase):
 
         self.test_reactor.pf_coil_radial_thicknesses = [30, 30, 30, 30]
         self.test_reactor.pf_coil_vertical_thicknesses = [30, 30, 30, 30]
-        self.test_reactor.pf_coil_to_tf_coil_radial_gap = 50
-        self.test_reactor.pf_coil_case_thickness = 10
+        self.test_reactor.rear_blanket_to_tf_gap = 50
+        self.test_reactor.pf_coil_case_thicknesses = 10
         self.test_reactor.outboard_tf_coil_radial_thickness = 30
         self.test_reactor.outboard_tf_coil_poloidal_thickness = 30
-        self.test_reactor.tf_coil_to_rear_blanket_radial_gap = 20
+        self.test_reactor.pf_coil_radial_position = [100, 100, 200, 200]
+        self.test_reactor.pf_coil_vertical_position = [100, -100, 200, -200]
         self.test_reactor.number_of_tf_coils = 16
 
         assert self.test_reactor.reactor_hash_value is None
@@ -208,7 +214,7 @@ class TestSubmersionTokamak(unittest.TestCase):
             "_pf_coil",
             "_pf_coils_casing"
         ]:
-            assert key not in self.test_reactor.__dict__.keys()
+            assert key not in self.test_reactor.__dict__
 
         assert self.test_reactor.shapes_and_components is not None
         for key in [
